﻿#pragma strict

var target : Transform;

var speed : float;
var smoothSpeed : float;
var rotateSpeed : float;
var turnSpeed : float;
var torque : float;

private var positionY = 0.0;
//private var rotationX = 0.0;
//private var rotationZ = 0.0;

private var isColliding : boolean = false;
var playing : boolean = false;
var isGameOver : boolean = false;

var barrelObject : GameObject;

var endVelocity = Vector3.zero;

private var boatModel : Transform;
private var boatY : float;

var rockCrash : AudioClip;

function Start () {
	boatModel = GameObject.Find("Rabelo").transform;
	
	yield WaitForSeconds (2);
	playing = true;
}

function FixedUpdate () {
	if (Input.GetKeyDown(KeyCode.Escape)) {
		Application.Quit(); 
	}
	
	if (playing) {
		//move to target
		//transform.position = Vector3.MoveTowards(transform.position, target.position, speed * Time.deltaTime);
		//transform.position = transform.position + transform.forward * speed;
		
		if (!isColliding){
			rigidbody.velocity = transform.forward * speed;
			
			var targetRotation : Quaternion = Quaternion.LookRotation(new Vector3(target.position.x, 0, target.position.z));
			transform.rotation = Quaternion.Slerp(transform.rotation, targetRotation, Time.deltaTime * rotateSpeed);
		}
		
		//rotate to face target
		//var targetRotation : Quaternion = Quaternion.LookRotation(new Vector3(target.position.x, 0, target.position.z));
		//transform.rotation = Quaternion.Slerp(transform.rotation, targetRotation, Time.deltaTime * rotateSpeed);
		//transform.LookAt(target, Vector3.up);
		
		//boat movement
		Move ();
		
		//Debug.DrawRay (transform.position, transform.forward, Color.cyan);
	}
	else if (isGameOver) {
		rigidbody.velocity = rigidbody.velocity * 0.98;
		rigidbody.angularVelocity = rigidbody.angularVelocity * 0.95;
		
		rigidbody.AddRelativeTorque (-transform.forward * 0);
	
		GameObject.Find("Camera").transform.RotateAround (transform.position, transform.up, 1);
	}
	
	//correct boat position
	BoatBalance ();
}

function OnCollisionEnter(collision : Collision) {
	isColliding = true;
	
	if (collision.gameObject.name == "Rock") {
		audio.PlayOneShot(rockCrash);
	
		GameObject.Find("GUI").SendMessage("UpdateScore", -10);
		
		// create the new object
		var throwBarrel = Instantiate (barrelObject, transform.position, transform.rotation);
		 
		// give it the same velocity as the current object
		throwBarrel.rigidbody.velocity = rigidbody.velocity + (throwBarrel.transform.right);
		throwBarrel.rigidbody.angularVelocity = rigidbody.angularVelocity;
		throwBarrel.transform.localScale = Vector3(throwBarrel.transform.localScale.x * 0.5,
													throwBarrel.transform.localScale.y * 0.5,
													throwBarrel.transform.localScale.z * 0.5);
		throwBarrel.rigidbody.useGravity = true;
		 
		// destroy this object
		yield WaitForSeconds (2);
		Destroy(throwBarrel);
	}
}

function OnCollisionExit(collision : Collision) {
	isColliding = false;
}

function OnTriggerEnter (collision : Collider) {
	if (collision.gameObject.name == "Barrel") {
		GameObject.Find("GUI").SendMessage("UpdateScore", 10);
		
		collision.SendMessage ("Explode");
	}
	
	if (collision.gameObject.name == "Endline") {
		isGameOver = true;
		playing = false;
		speed = 500;
		
		yield WaitForSeconds(2);
		GameObject.Find("Water").SendMessage("Stop");
		GameObject.Find("GUI").SendMessage("Finish");
	}
}

function BoatBalance () {
	var newPositionY : float = Mathf.SmoothDamp (transform.position.y, 15.1, positionY, smoothSpeed);
	transform.position.y = newPositionY;
	//transform.position.y = 15.5;
	
	//var newRotationX : float = Mathf.SmoothDamp (transform.eulerAngles.x, 0.0, rotationX, smoothSpeed);
	//var newRotationZ : float = Mathf.SmoothDamp (transform.eulerAngles.z, 0.0, rotationZ, smoothSpeed);
	//transform.eulerAngles = Vector3 (newRotationX, transform.eulerAngles.y, 0.0);
	
	var newBoatY : float;
	if (boatModel.localEulerAngles.y > 0 && boatModel.localEulerAngles.y < 2) {
		newBoatY = Mathf.SmoothDamp (boatModel.localEulerAngles.y, 0.0, boatY, 0.001);
		boatModel.localEulerAngles.y = newBoatY;
	}
	
	else if (boatModel.localEulerAngles.y > 358) {
		newBoatY = Mathf.SmoothDamp (boatModel.localEulerAngles.y, 360.0, boatY, 0.001);
		boatModel.localEulerAngles.y = newBoatY;
	}
}

function Move () {
	if (Input.GetKey (KeyCode.D)) {
		MoveRight ();
	}
	else if (Input.GetKey (KeyCode.A)) {
		MoveLeft ();
	}
	
	if (Input.GetKey (KeyCode.Space)) {
		speed = 500;
	}
	else {
		speed = 100;
	}
}

function MoveRight () {
	transform.position += transform.right * turnSpeed * Time.deltaTime;
	//rigidbody.velocity += transform.right * turnSpeed;
	//rigidbody.AddForce (transform.right * turnSpeed );
	
	rigidbody.AddRelativeTorque (-transform.forward * torque);
	
	if (boatModel.localEulerAngles.y < 1) {
		boatModel.localEulerAngles.y += 0.1;
		Debug.Log(boatModel.localEulerAngles.y);
	}
	
	if (boatModel.localEulerAngles.y >= 358.9) {
		boatModel.localEulerAngles.y += 0.1;
		Debug.Log(boatModel.localEulerAngles.y);
	}
}

function MoveLeft () {
	transform.position -= transform.right * turnSpeed * Time.deltaTime;
	//rigidbody.velocity -= transform.right * turnSpeed;
	//rigidbody.AddForce (-transform.right * turnSpeed );
	
	rigidbody.AddRelativeTorque (transform.forward * torque);
	
	if (boatModel.localEulerAngles.y > 359) {
		boatModel.localEulerAngles.y -= 0.1;
	}
	
	if (boatModel.localEulerAngles.y <= 1.1) {
		boatModel.localEulerAngles.y += -0.1;
	} 
	
	 
}
